@@ -6,10 +6,11 @@ use warnings;
 package Graphics::Toolkit::Color::Util;
 
 use Exporter 'import';
-our @EXPORT_OK = qw/round rmod/;
+our @EXPORT_OK = qw/round rmod close_enough/;
 our %EXPORT_TAGS = (all => [@EXPORT_OK]);
 
-my $half = 0.50000000000008;
+my $half      = 0.50000000000008;
+my $tolerance = 0.00000000000008;
 
 sub round {
     $_[0] >= 0 ? int ($_[0] + $half)
@@ -22,4 +23,6 @@ sub rmod {
     $_[0] - (int($_[0] / $_[1]) * $_[1]);
 }
 
+sub close_enough { abs($_[0] - $_[1]) < $tolerance if defined $_[1]}
+
 1;
